@@ -49,14 +49,14 @@ class R10K::Git::ShellGit::WorkingRepository < R10K::Git::ShellGit::BaseReposito
   # @param ref [String] The git reference to check out
   # @param opts [Hash] Optional hash of additional options.
   def checkout(ref, opts = {})
+    argv = ['checkout', ref]
+
     # :force defaults to true
     if !opts.has_key?(:force) || opts[:force]
-      force_opt = '--force'
-    else
-      force_opt = ''
+      argv << '--force'
     end
 
-    git ['checkout', ref, force_opt], :path => @path.to_s
+    git argv, :path => @path.to_s
   end
 
   def fetch(remote_name='origin')
@@ -90,8 +90,23 @@ class R10K::Git::ShellGit::WorkingRepository < R10K::Git::ShellGit::BaseReposito
   end
 
   # does the working tree have local modifications to tracked files?
-  def dirty?
-    result = git(['diff-index', '--quiet','HEAD', '--'], :path => @path.to_s, :raise_on_fail => false)
-    result.exit_code != 0
+  def dirty?(exclude_spec=true)
+    result = git(['diff-index', '--exit-code', '--name-only', 'HEAD'], :path => @path.to_s, :raise_on_fail => false)
+
+    if result.exit_code != 0
+      dirty_files = result.stdout.split("\n")
+      dirty_files.delete_if { |f| f.start_with?('spec/') } if exclude_spec
+
+      dirty_files.each do |file|
+        logger.debug(_("Found local modifications in %{file_path}" % {file_path: File.join(@path, file)}))
+
+        # Do this in a block so that the extra subprocess only gets invoked when needed.
+        logger.debug1 { git(['diff-index', '-p', 'HEAD', file], :path => @path.to_s, :raise_on_fail => false).stdout }
+      end
+
+      return dirty_files.size > 0
+    else
+      return false
+    end
   end
 end
