@@ -19,10 +19,14 @@ require 'r10k'
 Dir.glob(File.expand_path('spec/shared-examples/**/*.rb', PROJECT_ROOT)).each { |file| require file }
 
 require 'shared-contexts/git-fixtures'
+require 'shared-contexts/tarball'
 require 'matchers/exit_with'
 require 'matchers/match_realpath'
 require 'r10k-mocks'
 
+# Add a negated version of the change matcher.
+RSpec::Matchers.define_negated_matcher :not_change, :change
+
 RSpec.configure do |config|
   config.before(:all) do
     Log4r::Logger.global.level = Log4r::OFF
