@@ -66,17 +66,6 @@ describe R10K::Action::Deploy::Environment do
     it 'can accept an incremental option' do
       described_class.new({ :incremental => true }, [], {})
     end
-
-    describe "initializing errors" do
-      let (:settings) { { deploy: { purge_levels: [:environment],
-                                    purge_whitelist: ['coolfile', 'coolfile2'],
-                                    purge_allowlist: ['anothercoolfile']}}}
-
-      subject { described_class.new({config: "/some/nonexistent/path"}, [], settings)}
-      it 'errors out when both purge_whitelist and purge_allowlist are set' do
-        expect{subject}.to raise_error(R10K::Error, /Values found for both purge_whitelist and purge_allowlist./)
-    end
-   end
   end
 
   describe "when called" do
@@ -269,7 +258,7 @@ describe R10K::Action::Deploy::Environment do
       end
     end
 
-    describe "Purging white/allowlist" do
+    describe "Purging allowlist" do
 
       let(:settings) { { pool_size: 4, deploy: { purge_levels: [:environment], purge_allowlist: ['coolfile', 'coolfile2'] } } }
       let(:overrides) { { environments: {}, modules: { pool_size: 4 }, purging: { purge_levels: [:environment], purge_allowlist: ['coolfile', 'coolfile2'] } } }
@@ -288,16 +277,6 @@ describe R10K::Action::Deploy::Environment do
         expect(subject.settings[:overrides][:purging][:purge_allowlist]).to eq(['coolfile', 'coolfile2'])
         subject.call
       end
-
-      describe "purge_whitelist" do
-        let (:settings) { { deploy: { purge_levels: [:environment], purge_whitelist: ['coolfile', 'coolfile2'] } } }
-
-        it "reads in the purge_whitelist setting and still sets it to purge_allowlist and purges accordingly" do
-          expect(subject.logger).to receive(:debug).with(/Purging unmanaged content for environment/)
-          expect(subject.settings[:overrides][:purging][:purge_allowlist]).to eq(['coolfile', 'coolfile2'])
-          subject.call
-        end
-      end
     end
 
     describe "purge_levels" do
@@ -589,7 +568,7 @@ describe R10K::Action::Deploy::Environment do
 
     before(:all) do
       @tmp_path = "./tmp-r10k-test-dir/"
-      Dir.mkdir(@tmp_path) unless File.exists?(@tmp_path)
+      Dir.mkdir(@tmp_path) unless File.exist?(@tmp_path)
     end
 
     after(:all) do
